==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/js/JsMessageSearchResult.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.backend.mail.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsMessageSearchResult extends JavaScriptObject {

	protected JsMessageSearchResult() {}

	public final native String getContainerUid()
	/*-{
	return this["containerUid"];
	}-*/;

	public final native void setContainerUid(String containerUid)
	/*-{
       this["containerUid"] = containerUid;
	}-*/;

	public final native int getItemId()
	/*-{
	return this["itemId"];
	}-*/;

	public final native void setItemId(int itemId)
	/*-{
       this["itemId"] = itemId;
	}-*/;

	public final native String getSubject()
	/*-{
	return this["subject"];
	}-*/;

	public final native void setSubject(String subject)
	/*-{
       this["subject"] = subject;
	}-*/;

	public final native int getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(int size)
	/*-{
       this["size"] = size;
	}-*/;

	public final native String getMessageClass()
	/*-{
	return this["messageClass"];
	}-*/;

	public final native void setMessageClass(String messageClass)
	/*-{
       this["messageClass"] = messageClass;
	}-*/;

	public final native com.google.gwt.core.client.JsDate getDate()
	/*-{
       if(this["date"]) {
          return new Date(this["date"]);
       } else {
          return null;
       }
	}-*/;

	public final native void setDate(com.google.gwt.core.client.JsDate date)
	/*-{
       this["date"] =  ( date != null) ? date.getTime() : null;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox getFrom()
	/*-{
	return this["from"];
	}-*/;

	public final native void setFrom(net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox from)
	/*-{
       this["from"] = from;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox getTo()
	/*-{
	return this["to"];
	}-*/;

	public final native void setTo(net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox to)
	/*-{
       this["to"] = to;
	}-*/;

	public final native boolean getSeen()
	/*-{
	return this["seen"];
	}-*/;

	public final native void setSeen(boolean seen)
	/*-{
       this["seen"] = seen;
	}-*/;

	public final native boolean getFlagged()
	/*-{
	return this["flagged"];
	}-*/;

	public final native void setFlagged(boolean flagged)
	/*-{
       this["flagged"] = flagged;
	}-*/;

	public final native boolean getHasAttachment()
	/*-{
	return this["hasAttachment"];
	}-*/;

	public final native void setHasAttachment(boolean hasAttachment)
	/*-{
       this["hasAttachment"] = hasAttachment;
	}-*/;

	public final native String getPreview()
	/*-{
	return this["preview"];
	}-*/;

	public final native void setPreview(String preview)
	/*-{
       this["preview"] = preview;
	}-*/;

	public static native  JsMessageSearchResult create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.platform-5.4.2696.zip: net/bluemind/backend/mail/api/gwt/js/JsMessageSearchResult.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.backend.mail.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsMessageSearchResult extends JavaScriptObject {

	protected JsMessageSearchResult() {}

	public final native String getContainerUid()
	/*-{
	return this["containerUid"];
	}-*/;

	public final native void setContainerUid(String containerUid)
	/*-{
       this["containerUid"] = containerUid;
	}-*/;

	public final native java.lang.Long getItemId()
	/*-{
	return this["itemId"];
	}-*/;

	public final native void setItemId(java.lang.Long itemId)
	/*-{
       this["itemId"] = itemId;
	}-*/;

	public final native String getSubject()
	/*-{
	return this["subject"];
	}-*/;

	public final native void setSubject(String subject)
	/*-{
       this["subject"] = subject;
	}-*/;

	public final native int getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(int size)
	/*-{
       this["size"] = size;
	}-*/;

	public final native String getMessageClass()
	/*-{
	return this["messageClass"];
	}-*/;

	public final native void setMessageClass(String messageClass)
	/*-{
       this["messageClass"] = messageClass;
	}-*/;

	public final native com.google.gwt.core.client.JsDate getDate()
	/*-{
       if(this["date"]) {
          return new Date(this["date"]);
       } else {
          return null;
       }
	}-*/;

	public final native void setDate(com.google.gwt.core.client.JsDate date)
	/*-{
       this["date"] =  ( date != null) ? date.getTime() : null;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox getFrom()
	/*-{
	return this["from"];
	}-*/;

	public final native void setFrom(net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox from)
	/*-{
       this["from"] = from;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox getTo()
	/*-{
	return this["to"];
	}-*/;

	public final native void setTo(net.bluemind.backend.mail.api.gwt.js.JsMessageSearchResultMbox to)
	/*-{
       this["to"] = to;
	}-*/;

	public final native boolean getSeen()
	/*-{
	return this["seen"];
	}-*/;

	public final native void setSeen(boolean seen)
	/*-{
       this["seen"] = seen;
	}-*/;

	public final native boolean getFlagged()
	/*-{
	return this["flagged"];
	}-*/;

	public final native void setFlagged(boolean flagged)
	/*-{
       this["flagged"] = flagged;
	}-*/;

	public final native boolean getHasAttachment()
	/*-{
	return this["hasAttachment"];
	}-*/;

	public final native void setHasAttachment(boolean hasAttachment)
	/*-{
       this["hasAttachment"] = hasAttachment;
	}-*/;

	public final native String getPreview()
	/*-{
	return this["preview"];
	}-*/;

	public final native void setPreview(String preview)
	/*-{
       this["preview"] = preview;
	}-*/;

	public final native double getScore()
	/*-{
	return this["score"];
	}-*/;

	public final native void setScore(double score)
	/*-{
       this["score"] = score;
	}-*/;

	public static native  JsMessageSearchResult create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
